@@ -1,9 +1,9 @@
-__version__ = "0.0.20"
+__version__ = "0.1.0"
 
 from . import _measurements as measurements
 from . import _approximation as approximation
+from . import _reconstruction as reconstruction
 
-from ._refine_surfaces import trace_refinement_of_surface
 from ._preprocess import rescale
 from ._surface import adjust_surface_density,\
     smooth_sinc,\
@@ -19,7 +19,7 @@ from ._utils.frame_by_frame import TimelapseConverter, frame_by_frame
 from ._spherical_harmonics.spherical_harmonics_napari import fit_spherical_harmonics
 from ._spherical_harmonics.spherical_harmonics import lebedev_quadrature, create_manifold
 
-from ._sample_data import get_droplet_point_cloud, get_droplet_point_cloud_4d
+from ._sample_data import get_droplet_point_cloud, get_droplet_point_cloud_4d, get_droplet_4d
 
 from ._plotting.features_histogram import FeaturesHistogramWidget
 
