@@ -22,3 +22,15 @@ def get_droplet_point_cloud_4d() -> LayerDataTuple:
     coordinates = df[['axis-0', 'axis-1', 'axis-2', 'axis-3']].to_numpy()
 
     return [(coordinates, {'size': 0.5, 'face_color': 'orange'}, 'points')]
+
+def get_droplet_4d() -> LayerDataTuple:
+    """
+    Loads a sample 4d point cloud of a droplet surface.
+
+    Source:https://github.com/campaslab/STRESS
+    """
+    from skimage import io
+
+    image = io.imread(os.path.join(DATA_ROOT, 'ExampleTifSequence.tif'))
+
+    return [(image, {}, 'image')]
